# SQLAlchemy Model CRUD

![https://coveralls.io/repos/z4r/python-coveralls/badge.png?branch=master](https://coveralls.io/repos/z4r/python-coveralls/badge.png?branch=master)

Base CRUD manager to manage databases with asynchronous SQLAlchemy sessions.


- Repository: [https://github.com/lucaslucyk/sa-model-crud](https://github.com/lucaslucyk/sa-model-crud)
- PyPi: [https://pypi.org/project/sa-model-crud](https://pypi.org/project/sa-model-crud)
- Documentation: Coming soon.


## Project Status
⚠️ **_Warning_**: This project is currently in __*development phase*__.

This project is in an early stage of development and may contain bugs. It is not recommended for use in production environments.


## Install
```bash
$  pip install sa-model-crud
```


## Quickstart

`coming soon`


## Contributions and Feedback
I would love to receive contributions and feedback! If you'd like to get involved, please contact me through one of the contact methods in my [Profile](https://github.com/lucaslucyk).


## License
This project is licensed under the terms of the MIT license.